aboutsummaryrefslogtreecommitdiffstats
path: root/options.go
diff options
context:
space:
mode:
Diffstat (limited to 'options.go')
-rw-r--r--options.go8
1 files changed, 4 insertions, 4 deletions
diff --git a/options.go b/options.go
index d0898db..9fb315e 100644
--- a/options.go
+++ b/options.go
@@ -369,16 +369,16 @@ type CleanOptions struct {
// GrepOptions describes how a grep should be performed.
type GrepOptions struct {
- // Pattern is a compiled Regexp object to be matched.
- Pattern *regexp.Regexp
+ // Patterns are compiled Regexp objects to be matched.
+ Patterns []*regexp.Regexp
// InvertMatch selects non-matching lines.
InvertMatch bool
// CommitHash is the hash of the commit from which worktree should be derived.
CommitHash plumbing.Hash
// ReferenceName is the branch or tag name from which worktree should be derived.
ReferenceName plumbing.ReferenceName
- // PathSpec is a compiled Regexp object of pathspec to use in the matching.
- PathSpec *regexp.Regexp
+ // PathSpecs are compiled Regexp objects of pathspec to use in the matching.
+ PathSpecs []*regexp.Regexp
}
var (